#!/bin/sh
# 
# chkconfig: 345 99 01
# description: Netsaint network monitor
#
# File : netsaint
#
# Author : Jorge Sanchez Aymar (jsanchez@lanchile.cl)
# 
# Changelog :
#
# 1999-07-09 Karl DeBisschop <kdebisschop@infoplease.com>
#  - setup for autoconf
#  - add reload function
# 1999-08-06 Ethan Galstad <netsaint@linuxbox.com>
#  - Added configuration info for use with RedHat's chkconfig tool
#    per Fran Boon's suggestion
# 1999-08-13 Jim Popovitch <jimpop@rocketship.com>
#  - added variable for netsaint/var directory
#  - cd into netsaint/var directory before creating tmp files on startup
# 1999-08-16 Ethan Galstad <netsaint@linuxbox.com>
#  - Added test for rc.d directory as suggested by Karl DeBisschop
#
# Description: Starts and stops the Netsaint monitor
#              used to provide network services status.
#
  
# Source function library
# Solaris doesn't have an rc.d directory, so do a test first
if [ -f /usr/local/etc/netsaint/functions ]; then
. /usr/local/etc/netsaint/functions
else
   echo "/usr/local/etc/netsaint/functions missing"
   exit 1
fi

prefix=/usr/local
exec_prefix=${prefix}
NetsaintBin=${exec_prefix}/bin/netsaint
NetsaintCfg=${prefix}/etc/netsaint/netsaint.cfg
NetsaintLog=${prefix}/var/netsaint/status.log
NetsaintTmp=${prefix}/var/netsaint/netsaint.tmp
NetSaintVar=${prefix}/var/netsaint
Netsaint=netsaint
          
# Check that netsaint.cfg exists.
[ -f $NetsaintCfg ] || exit 0
          
# See how we were called.
case "$1" in
  start)
        printf %s "Starting Netsaint service: "
        su $Netsaint -c "$NetsaintBin -d $NetsaintCfg"
        status netsaint
        ;;
  stop)
        printf %s "Shutting down Netsaint service: "
        killproc netsaint
	rm -f $NetsaintLog $NetsaintTmp $NetsaintLck
        echo ""
        ;;
  status)
        status netsaint
        ;;  
  restart)
	if $NetsaintBin -v $NetsaintCfg > /dev/null 2>&1; then
	    echo "Passed configuration check - restarting... "
	    $0 stop
	    $0 start
	    echo "done."
	else
	    echo "Error in configuration files - aborting restart."
	fi
        ;;
  reload)
	if $NetsaintBin -v $NetsaintCfg > /dev/null 2>&1; then
	    printf %s "Passed configuration check - reloading configuration... "
	    killproc netsaint -HUP
	    echo "done."
	else
	    echo "Erorr in configuration files - aborting reload."
	fi
        ;;
  *)
        echo "Usage: netsaint {start|stop|restart|reload|status}"
        exit 1
esac
  
# End of this script
